package com.ruoyi.powerdistribution.service;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmStopTarge;
import com.ruoyi.powerdistribution.domain.vo.StopTargetAndRecords;

/**
 * 停电预算Service接口
 *
 * @author ruoyi
 * @date 2024-12-09
 */
public interface IPdmStopTargeService
{
    /**
     * 查询停电预算
     *
     * @param id 停电预算主键
     * @return 停电预算
     */
    public PdmStopTarge selectPdmStopTargeById(Long id);

    /**
     * 查询停电预算列表
     *
     * @param pdmStopTarge 停电预算
     * @return 停电预算集合
     */
    public List<PdmStopTarge> selectPdmStopTargeList(PdmStopTarge pdmStopTarge);

    /**
     * 新增停电预算
     *
     * @param pdmStopTarge 停电预算
     * @return 结果
     */
    public int insertPdmStopTarge(PdmStopTarge pdmStopTarge);

    /**
     * 修改停电预算
     *
     * @param pdmStopTarge 停电预算
     * @return 结果
     */
    public int updatePdmStopTarge(PdmStopTarge pdmStopTarge);

    /**
     * 批量删除停电预算
     *
     * @param ids 需要删除的停电预算主键集合
     * @return 结果
     */
    public int deletePdmStopTargeByIds(Long[] ids);

    /**
     * 删除停电预算信息
     *
     * @param id 停电预算主键
     * @return 结果
     */
    public int deletePdmStopTargeById(Long id);

    /**
     * 按年份批量保存
     * @param list
     * @param reportYear 目标年份
     * @return
     */
    boolean batchSaveOrUpdate(List<PdmStopTarge> list,String reportYear);

    /**
     * 获取停电完成情况
     * @param reportYear
     * @return
     */
    List<StopTargetAndRecords> selectTargetAndActual(String reportYear);
}
